The highest tagged major version is
v3.
package
Version:
v1.3.6
Opens a new window with list of versions in this module.
Published: May 26, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ResponseBillGet struct {
HashType string `json:"hash_type"`
HashValue string `json:"hash_value"`
DownloadURL string `json:"download_url"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.